BOOST_PP_LESS

The BOOST_PP_LESS macro compares two values for lesser magnitude.

#### Usage

BOOST_PP_LESS(x, y)

#### Arguments

x
  The left operand of the comparison. Valid values range from 0 to BOOST_PP_LIMIT_MAG.
y
  The right operand of the comparison. Valid values range from 0 to BOOST_PP_LIMIT_MAG.

#### Remarks

If x is less than y, this macro expands to 1. Otherwise, it expands to 0.
Previously, this macro could not be used inside BOOST_PP_WHILE. There is no longer any such restriction. It is more efficient, however, to use BOOST_PP_LESS_D in such a situation.

#### See Also

- BOOST_PP_LESS_D
- BOOST_PP_LIMIT_MAG

#### Requirements

Header: <boost/preprocessor/comparison/less.hpp>

#### Sample Code

    #include <boost/preprocessor/comparison/less.hpp>

    BOOST_PP_LESS(4, 3) // expands to 0
    BOOST_PP_LESS(3, 4) // expands to 1

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)